MultiThreadedExecutor

Struct MultiThreadedExecutor 

pub struct MultiThreadedExecutor { /* private fields */ }
Service / action / subscription / timer callbacks run on a resident worker pool (ROS 2 MultiThreadedExecutor), subject to each crate::runtime::CallbackGroup’s type.

Implementations

Source

impl MultiThreadedExecutor

pub fn new(num_threads: usize) -> Self

num_threads resident worker threads pulling from a shared job queue.

pub fn with_context(context: Context, num_threads: usize) -> Self

Like new, sharing context for ZMQ sockets.

pub fn handle(&self) -> &ExecutorHandle

pub fn add_node(&self, node: &mut Node) -> Result<()>

pub fn create_node(&self, name: impl Into<String>) -> Result<Node>

pub fn create_node_with_options( &self, name: impl Into<String>, options: NodeOptions, ) -> Result<Node>

pub fn create_node_with_context( &self, context: &Context, name: impl Into<String>, options: NodeOptions, ) -> Result<Node>

pub fn shutdown_handle(&self) -> Result<ShutdownHandle>

pub fn shutdown(&self) -> Result<()>

pub fn spin_once(&self, timeout: Option<Duration>) -> Result<bool>

pub fn spin_some(&self, timeout: Option<Duration>) -> Result<()>

pub fn spin(&self) -> Result<()>

pub fn start(&self) -> Result<()>

pub fn stop(&self) -> Result<()>

pub fn wait(&self) -> Result<()>